@@ -67,9 +67,9 @@ Experimental
 
 Starting with IPython 6.0, this module can make use of the Jedi library to
 generate completions both using static analysis of the code, and dynamically
-inspecting multiple namespaces. The APIs attached to this new mechanism is
-unstable and will raise unless use in an :any:`provisionalcompleter` context
-manager.
+inspecting multiple namespaces. Jedi is an autocompletion and static analysis
+for Python. The APIs attached to this new mechanism is unstable and will
+raise unless use in an :any:`provisionalcompleter` context manager.
 
 You will find that the following are experimental:
 
@@ -84,7 +84,7 @@ You will find that the following are experimental:
 
 We welcome any feedback on these new API, and we also encourage you to try this
 module in debug mode (start IPython with ``--Completer.debug=True``) in order
-to have extra logging information is :any:`jedi` is crashing, or if current
+to have extra logging information if :any:`jedi` is crashing, or if current
 IPython completer pending deprecations are returning results not yet handled
 by :any:`jedi`
 
@@ -185,11 +185,11 @@ def provisionalcompleter(action='ignore'):
     """
 
 
-    This contest manager has to be used in any place where unstable completer
+    This context manager has to be used in any place where unstable completer
     behavior and API may be called.
 
     >>> with provisionalcompleter():
-    ...     completer.do_experimetal_things() # works
+    ...     completer.do_experimental_things() # works
 
     >>> completer.do_experimental_things() # raises.
 
@@ -198,12 +198,11 @@ def provisionalcompleter(action='ignore'):
         By using this context manager you agree that the API in use may change
         without warning, and that you won't complain if they do so.
 
-        You also understand that if the API is not to you liking you should report
-        a bug to explain your use case upstream and improve the API and will loose
-        credibility if you complain after the API is make stable.
+        You also understand that, if the API is not to your liking, you should report
+        a bug to explain your use case upstream.
 
-        We'll be happy to get your feedback , feature request and improvement on
-        any of the unstable APIs !
+        We'll be happy to get your feedback, feature requests, and improvements on
+        any of the unstable APIs!
     """
     with warnings.catch_warnings():
         warnings.filterwarnings(action, category=ProvisionalCompleterWarning)
@@ -576,9 +575,9 @@ class Completer(Configurable):
         """
     ).tag(config=True)
 
-    use_jedi = Bool(default_value=False,
+    use_jedi = Bool(default_value=JEDI_INSTALLED,
                     help="Experimental: Use Jedi to generate autocompletions. "
-                    "Off by default.").tag(config=True)
+                    "Default to True if jedi is installed.").tag(config=True)
 
     jedi_compute_type_timeout = Int(default_value=400,
         help="""Experimental: restrict time (in milliseconds) during which Jedi can compute types.
@@ -992,6 +991,8 @@ def _make_signature(completion)-> str:
 class IPCompleter(Completer):
     """Extension of the completer class with IPython-specific features"""
 
+    _names = None
+
     @observe('greedy')
     def _greedy_changed(self, change):
         """update the splitter and readline delims when greedy is changed"""
@@ -1134,10 +1135,15 @@ class IPCompleter(Completer):
                 self.dict_key_matches,
             ]
 
-    def all_completions(self, text):
+    def all_completions(self, text) -> List[str]:
         """
-        Wrapper around the complete method for the benefit of emacs.
+        Wrapper around the completion methods for the benefit of emacs.
         """
+        prefix = text.rpartition('.')[0]
+        with provisionalcompleter():
+            return ['.'.join([prefix, c.text]) if prefix and self.use_jedi else c.text
+                    for c in self.completions(text, len(text))]
+
         return self.complete(text)[1]
 
     def _clean_glob(self, text):
@@ -1538,24 +1544,19 @@ class IPCompleter(Completer):
 
             usedNamedArgs.add(token)
 
-        # lookup the candidate callable matches either using global_matches
-        # or attr_matches for dotted names
-        if len(ids) == 1:
-            callableMatches = self.global_matches(ids[0])
-        else:
-            callableMatches = self.attr_matches('.'.join(ids[::-1]))
         argMatches = []
-        for callableMatch in callableMatches:
-            try:
-                namedArgs = self._default_arguments(eval(callableMatch,
-                                                        self.namespace))
-            except:
-                continue
+        try:
+            callableObj = '.'.join(ids[::-1])
+            namedArgs = self._default_arguments(eval(callableObj,
+                                                    self.namespace))
 
             # Remove used named arguments from the list, no need to show twice
             for namedArg in set(namedArgs) - usedNamedArgs:
                 if namedArg.startswith(text):
                     argMatches.append(u"%s=" %namedArg)
+        except:
+            pass
+
         return argMatches
 
     def dict_key_matches(self, text):
@@ -1989,7 +1990,8 @@ class IPCompleter(Completer):
                 return latex_text, latex_matches, ['latex_matches']*len(latex_matches), ()
             name_text = ''
             name_matches = []
-            for meth in (self.unicode_name_matches, back_latex_name_matches, back_unicode_name_matches):
+            # need to add self.fwd_unicode_match() function here when done
+            for meth in (self.unicode_name_matches, back_latex_name_matches, back_unicode_name_matches, self.fwd_unicode_match):
                 name_text, name_matches = meth(base_text)
                 if name_text:
                     return name_text, name_matches[:MATCHES_LIMIT], \
@@ -2064,3 +2066,26 @@ class IPCompleter(Completer):
         self.matches = _matches
 
         return text, _matches, origins, completions
+
+    def fwd_unicode_match(self, text:str) -> Tuple[str, list]:
+        if self._names is None:
+            self._names = []
+            for c in range(0,0x10FFFF + 1):
+                try:
+                    self._names.append(unicodedata.name(chr(c)))
+                except ValueError:
+                    pass
+
+        slashpos = text.rfind('\\')
+        # if text starts with slash
+        if slashpos > -1:
+            s = text[slashpos+1:]
+            candidates = [x for x in self._names if x.startswith(s)]
+            if candidates:
+                return s, candidates
+            else:
+                return '', ()
+
+        # if text does not start with slash
+        else:
+            return u'', ()
